This function is used in the demo workflows to demonstrate how to run a workflow step that performs a simple operation.
Examples
sum_step(list(value = 5), 3)
#> [1] 8
This function is used in the demo workflows to demonstrate how to run a workflow step that performs a simple operation.
sum_step(list(value = 5), 3)
#> [1] 8